==> xinlake_platform-0.1.4.tar.gz: lib/xinlake_platform.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

enum CacheDir { none, internalCache, internalFiles, externalCache, externalFiles }

class XinlakePlatform {
  static const MethodChannel _channel = MethodChannel('xinlake_platform');

  /// * [return]: A list contains files picked, an empty list if the action was canceled,
  /// null if error occurs
  /// * [isMultiSelection]: Multiple selection
  /// ***
  /// Android. READ_EXTERNAL_STORAGE permission is required.
  /// * [mimeType]: Acceptable MIME types such as "image/jpeg", "audio/*", "application/xyz"
  /// * [cacheDir]:
  /// * [isForceCache]:
  /// ***
  /// Windows.
  /// * [openPath]: Path to open
  /// * [defaultPath]: Default open folder for the dialog, if [openPath] is set
  /// then [defaultPath] will be ignored.
  /// * [filterName]: Friendly name of the filter such as "JPEG Image"
  /// * [filterPattern]: Filter pattern such as "*.jpg; *.jpeg"
  static Future<List<String>?> pickFiles({
    bool isMultiSelection = false,
    // android
    String mimeType = "*/*",
    CacheDir cacheDir = CacheDir.none,
    bool isForceCache = false,
    // windows
    String? openPath,
    String? defaultPath,
    required String filterName,
    required String filterPattern,
  }) async {
    try {
      return await _channel.invokeListMethod('pickFiles', {
        "isMultiSelection": isMultiSelection,
        "mimeType": mimeType,
        "cacheDirIndex": cacheDir.index,
        "isForceCache": isForceCache,
        "openPath": openPath ?? "",
        "defaultPath": defaultPath ?? "",
        "filterName": filterName,
        "filterPattern": filterPattern,
      });
    } catch (error) {
      return null;
    }
  }

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}

==> xinlake_platform-0.1.5.tar.gz: lib/xinlake_platform.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

enum AndroidCacheDir { none, internalCache, internalFiles, externalCache, externalFiles }

class XinlakePlatform {
  static const MethodChannel _channel = MethodChannel('xinlake_platform');

  /// Returns a list contains files picked, an empty list if the action was canceled,
  /// null if error occurs
  /// * [multiSelection]: Multiple selection
  /// ***
  /// Android. READ_EXTERNAL_STORAGE permission is required.
  /// * [mimeType]: Acceptable MIME types such as "image/jpeg", "audio/*", "application/xyz"
  /// * [cacheDir]:
  /// * [forceCache]: This parameter will be ignored if cacheDir is AndroidCacheDir.none
  /// ***
  /// Windows.
  /// * [openPath]: Path to open
  /// * [defaultPath]: Default open folder for the dialog, if openPath is set
  /// then defaultPath will be ignored.
  /// * [filterName]: Friendly name of the filter such as "JPEG Image"
  /// * [filterPattern]: Filter pattern such as "*.jpg; *.jpeg"
  static Future<List<String>?> pickFiles({
    bool multiSelection = false,
    // android
    String mimeType = "*/*",
    AndroidCacheDir cacheDir = AndroidCacheDir.none,
    bool forceCache = false,
    // windows
    String? openPath,
    String? defaultPath,
    required String filterName,
    required String filterPattern,
  }) async {
    try {
      return await _channel.invokeListMethod('pickFiles', {
        "multiSelection": multiSelection,
        "mimeType": mimeType,
        "cacheDirIndex": cacheDir.index,
        "forceCache": forceCache,
        "openPath": openPath ?? "",
        "defaultPath": defaultPath ?? "",
        "filterName": filterName,
        "filterPattern": filterPattern,
      });
    } catch (error) {
      return null;
    }
  }

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}
